@@ -14,8 +14,10 @@
 
 import asyncio
 import datetime
+from enum import Enum
 
-async def async_sleep_until_next_multiply_of_minutes(minutes):
+
+async def async_sleep_until_next_multiply_of_minutes(minutes: int) -> None:
     next = datetime.datetime.now() + datetime.timedelta(minutes=minutes)
     next_rounded = datetime.datetime(
         year=next.year,
@@ -24,7 +26,11 @@ async def async_sleep_until_next_multiply_of_minutes(minutes):
         hour=next.hour,
         minute=next.minute // minutes * minutes,
         second=0,
-        microsecond=0
+        microsecond=0,
     )
 
     await asyncio.sleep((next_rounded - datetime.datetime.now()).total_seconds())
+
+
+def pretty_enum_name(enum: Enum) -> str:
+    return enum.name.title().replace("_", " ")
